@@ -103,7 +103,7 @@ struct OPALSpark: public Ekiga::Spark
     boost::shared_ptr<Ekiga::AudioOutputCore> audiooutput_core = core.get<Ekiga::AudioOutputCore> ("audiooutput-core");
     boost::shared_ptr<Ekiga::VideoOutputCore> videooutput_core = core.get<Ekiga::VideoOutputCore> ("videooutput-core");
     boost::shared_ptr<Ekiga::PersonalDetails> personal_details = core.get<Ekiga::PersonalDetails> ("personal-details");
-    Ekiga::ServicePtr account_store = core.get ("opal-account-store");
+    boost::shared_ptr<Bank> account_store = core.get<Bank> ("opal-account-store");
     Ekiga::ServicePtr sip_endpoint = core.get ("opal-sip-endpoint");
 
     if (contact_core && presence_core && call_core && chat_core
@@ -114,8 +114,9 @@ struct OPALSpark: public Ekiga::Spark
       hook_ekiga_plugins_to_opal (core);
 
       boost::shared_ptr<CallManager> call_manager (new CallManager (core));
+      core.add (call_manager);
 
-      boost::shared_ptr<Opal::Bank> bank (new Bank (core));
+      boost::shared_ptr<Bank> bank (new Bank (core));
 
       account_core->add_bank (bank);
       core.add (bank);
@@ -123,12 +124,14 @@ struct OPALSpark: public Ekiga::Spark
 
       unsigned sip_port = gm_conf_get_int (SIP_KEY "listen_port");
       boost::shared_ptr<Sip::EndPoint> sip_manager (new Sip::EndPoint (*call_manager, core, sip_port));
+      core.add (sip_manager);
+
       call_manager->add_protocol_manager (sip_manager);
       contact_core->add_contact_decorator (sip_manager);
       presence_core->add_presentity_decorator (sip_manager);
-      presence_core->add_presence_fetcher (sip_manager);
-      presence_core->add_presence_publisher (sip_manager);
-      core.add (sip_manager);
+
+      presence_core->add_presence_publisher (bank);
+      presence_core->add_presence_fetcher (bank);
 
 #ifdef HAVE_H323
       unsigned h323_port = gm_conf_get_int (H323_KEY "listen_port");
@@ -141,8 +144,6 @@ struct OPALSpark: public Ekiga::Spark
 
       call_core->add_manager (call_manager);
 
-      core.add (call_manager);
-
       new ConfBridge (*call_manager); // FIXME: isn't that leaked!?
 
       presence_core->add_supported_uri (&is_supported_address); //FIXME
