@@ -33,7 +33,15 @@
  *
  */
 
+
+/* set DEBUG to 1 and the service core will tell whenever something is added or
+ * asked to it...
+ */
+#define DEBUG 0
+
+#if DEBUG
 #include <iostream>
+#endif
 
 #include "services.h"
 
@@ -42,17 +50,16 @@ Ekiga::ServiceCore::~ServiceCore ()
   /* this frees the memory, if we're the only to hold references,
    * and frees the last first -- so there's no problem
    */
-  while (services.begin () != services.end ())
+  while ( !services.empty ())
     services.pop_front ();
 }
 
 bool
-Ekiga::ServiceCore::add (gmref_ptr<Service> service)
+Ekiga::ServiceCore::add (ServicePtr service)
 {
   bool result = false;
 
   if ( !get (service->get_name ())) {
-
     services.push_front (service);
     service_added (service);
     result = true;
@@ -60,30 +67,44 @@ Ekiga::ServiceCore::add (gmref_ptr<Service> service)
 
     result = false;
   }
+#if DEBUG
+  if (result)
+    std::cout << "Ekiga::ServiceCore added " << service->get_name () << std::endl;
+  else
+    std::cout << "Ekiga::ServiceCore already has " << service->get_name () << std::endl;
+#endif
 
   return result;
 }
 
-gmref_ptr<Ekiga::Service>
+Ekiga::ServicePtr
 Ekiga::ServiceCore::get (const std::string name)
 {
-  gmref_ptr<Service> result;
+  ServicePtr result;
 
-  for (std::list<gmref_ptr<Service> >::iterator iter = services.begin ();
+  for (services_type::iterator iter = services.begin ();
        iter != services.end () && !result;
        iter++)
     if (name == (*iter)->get_name ()) {
 
       result = *iter;
     }
+
+
+#if DEBUG
+  if (result)
+    std::cout << "Ekiga::ServiceCore returns " << name << std::endl;
+  else
+    std::cout << "Ekiga::ServiceCore doesn't have " << name << std::endl;
+#endif
+
   return result;
 }
 
 void
 Ekiga::ServiceCore::dump (std::ostream &stream) const
 {
-  for (std::list<gmref_ptr<Service> >::const_reverse_iterator iter
-	 = services.rbegin ();
+  for (services_type::const_reverse_iterator iter = services.rbegin ();
        iter != services.rend ();
        iter++)
     stream << (*iter)->get_name ()
