@@ -220,9 +220,11 @@ public:
 
   TextSubmitter (const std::string _name,
 		 const std::string _description,
+		 const std::string _tooltip,
 		 bool _advanced,
 		 GtkWidget *_widget): name(_name),
 				      description(_description),
+				      tooltip(_tooltip),
 				      advanced(_advanced),
 				      widget(_widget)
   { }
@@ -233,7 +235,7 @@ public:
   void submit (Ekiga::FormBuilder &builder)
   {
     builder.text (name, description,
-		  gtk_entry_get_text (GTK_ENTRY (widget)),
+          gtk_entry_get_text (GTK_ENTRY (widget)), tooltip,
 		  advanced);
   }
 
@@ -241,6 +243,7 @@ private:
 
   const std::string name;
   const std::string description;
+  const std::string tooltip;
   bool advanced;
   GtkWidget *widget;
 };
@@ -266,13 +269,14 @@ public:
   {
     builder.private_text (name, description,
 			  gtk_entry_get_text (GTK_ENTRY (widget)),
-			  advanced);
+			  tooltip, advanced);
   }
 
 private:
 
   const std::string name;
   const std::string description;
+  const std::string tooltip;
   bool advanced;
   GtkWidget *widget;
 };
@@ -621,7 +625,7 @@ link_clicked_cb (GtkWidget * /*widget*/,
 }
 
 
-FormDialog::FormDialog (Ekiga::FormRequest &_request,
+FormDialog::FormDialog (Ekiga::FormRequestPtr _request,
 			GtkWidget *parent): request(_request)
 {
   GtkWidget *vbox = NULL;
@@ -664,7 +668,7 @@ FormDialog::FormDialog (Ekiga::FormRequest &_request,
   labels_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
   options_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-  request.visit (*this);
+  request->visit (*this);
 }
 
 
@@ -754,7 +758,7 @@ FormDialog::link (const std::string _link,
   gtk_button_set_relief (GTK_BUTTON (widget), GTK_RELIEF_NONE);
   gtk_box_pack_start (GTK_BOX (preamble), widget, FALSE, FALSE, 0);
 
-  g_signal_connect_data (G_OBJECT (widget), "clicked",
+  g_signal_connect_data (widget, "clicked",
                          G_CALLBACK (link_clicked_cb), (gpointer) g_strdup (_uri.c_str ()),
                          (GClosureNotify) g_free, (GConnectFlags) 0);
 }
@@ -818,6 +822,7 @@ void
 FormDialog::text (const std::string name,
 		  const std::string description,
 		  const std::string value,
+		  const std::string tooltip,
 		  bool advanced)
 {
   GtkWidget *label = NULL;
@@ -836,6 +841,7 @@ FormDialog::text (const std::string name,
   g_free (label_text);
 
   widget = gtk_entry_new ();
+  gtk_widget_set_tooltip_text (widget, tooltip.c_str ());
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
   gtk_entry_set_activates_default (GTK_ENTRY (widget), true);
   gtk_size_group_add_widget (options_group, widget);
@@ -867,7 +873,7 @@ FormDialog::text (const std::string name,
 		      0, 0);
   }
 
-  submitter = new TextSubmitter (name, description, advanced, widget);
+  submitter = new TextSubmitter (name, description, tooltip, advanced, widget);
   submitters.push_back (submitter);
 }
 
@@ -876,6 +882,7 @@ void
 FormDialog::private_text (const std::string name,
 			  const std::string description,
 			  const std::string value,
+			  const std::string tooltip,
 			  bool advanced)
 {
   GtkWidget *label = NULL;
@@ -894,6 +901,7 @@ FormDialog::private_text (const std::string name,
   g_free (label_text);
 
   widget = gtk_entry_new ();
+  gtk_widget_set_tooltip_text (widget, tooltip.c_str ());
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
   gtk_entry_set_activates_default (GTK_ENTRY (widget), true);
   gtk_entry_set_visibility (GTK_ENTRY (widget), FALSE);
@@ -1118,7 +1126,7 @@ FormDialog::multiple_choice (const std::string name,
                                               "active", MultipleChoiceSubmitter::COLUMN_ACTIVE,
                                               NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-  g_signal_connect (G_OBJECT (renderer), "toggled",
+  g_signal_connect (renderer, "toggled",
                     G_CALLBACK (multiple_choice_choice_toggled_cb), list_store);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -1230,7 +1238,7 @@ FormDialog::editable_set (const std::string name,
                                               "active", EditableSetSubmitter::COLUMN_ACTIVE,
                                               NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
-  g_signal_connect (G_OBJECT (renderer), "toggled",
+  g_signal_connect (renderer, "toggled",
                     G_CALLBACK (editable_set_choice_toggled_cb), list_store);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -1297,11 +1305,11 @@ FormDialog::editable_set (const std::string name,
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 2);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
 
-  g_signal_connect (G_OBJECT (entry), "activate",
+  g_signal_connect (entry, "activate",
 		    (GCallback) editable_set_add_value_activated_cb,
 		    (gpointer) tree_view);
 
-  g_signal_connect (G_OBJECT (button), "clicked",
+  g_signal_connect (button, "clicked",
 		    (GCallback) editable_set_add_value_clicked_cb,
 		    (gpointer) entry);
 
@@ -1333,21 +1341,21 @@ FormDialog::submit ()
 {
   Ekiga::FormBuilder builder;
 
-  gtk_widget_hide_all (GTK_WIDGET (window));
+  gtk_widget_hide (GTK_WIDGET (window));
 
   for (std::list<Submitter *>::iterator iter = submitters.begin ();
        iter != submitters.end ();
        iter++)
     (*iter)->submit (builder);
 
-  request.submit (builder);
+  request->submit (builder);
 }
 
 void
 FormDialog::cancel ()
 {
-  gtk_widget_hide_all (GTK_WIDGET (window));
-  request.cancel ();
+  gtk_widget_hide (GTK_WIDGET (window));
+  request->cancel ();
 }
 
 void
