@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ G_BEGIN_DECLS
 
 /* public api */
 
-GtkWidget* multiple_chat_page_new (Ekiga::MultipleChat& chat);
+GtkWidget* multiple_chat_page_new (Ekiga::MultipleChatPtr chat);
 
 /* GObject boilerplate */
 
