@@ -130,7 +130,7 @@ XWindow::XWindow()
 #ifdef HAVE_SHM
   _XShmInfo.shmaddr = NULL;
 #endif
- _scalingAlgorithm = NULL;
+ _scalingAlgorithm = PIXOPS_INTERP_NEAREST;
 }
 
 
@@ -271,7 +271,7 @@ XWindow::Init (Display* dp,
   if (!_colorConverter)
     return 0;
 
-  _frameBuffer = std::tr1::shared_ptr<void> (malloc (_imageWidth * _imageHeight * _planes), free);
+  _frameBuffer = boost::shared_ptr<void> (malloc (_imageWidth * _imageHeight * _planes), free);
 
   // detect the window manager type
   _wmType = GetWMType ();
