@@ -50,6 +50,8 @@
 #include "ldap-book.h"
 #include "robust-xml.h"
 
+#define EKIGA_NET_URI "ldap://ekiga.net"
+
 /* little helper function... can probably be made more complete */
 static const std::string
 fix_to_utf8 (const std::string str)
@@ -187,7 +189,6 @@ OPENLDAP::Book::Book (Ekiga::ServiceCore &_core,
   bookinfo.authcID = "";
   bookinfo.password = "";
   bookinfo.saslMech = "";
-  bookinfo.urld = NULL;
   bookinfo.sasl = false;
   bookinfo.starttls = false;
 
@@ -334,6 +335,10 @@ OPENLDAP::Book::Book (Ekiga::ServiceCore &_core,
     trigger_saving ();
   }
   OPENLDAP::BookInfoParse (bookinfo);
+  if (bookinfo.uri_host == EKIGA_NET_URI)
+    I_am_an_ekiga_net_book = true;
+  else
+    I_am_an_ekiga_net_book = false;
 }
 
 OPENLDAP::Book::Book (Ekiga::ServiceCore &_core,
@@ -367,11 +372,20 @@ OPENLDAP::Book::Book (Ekiga::ServiceCore &_core,
 			       BAD_CAST robust_xmlEscape (node->doc,
 							  bookinfo.password).c_str ());
   OPENLDAP::BookInfoParse (bookinfo);
+  if (bookinfo.uri_host == EKIGA_NET_URI)
+    I_am_an_ekiga_net_book = true;
+  else
+    I_am_an_ekiga_net_book = false;
 }
 
 OPENLDAP::Book::~Book ()
 {
-  if (bookinfo.urld) ldap_free_urldesc(bookinfo.urld);
+}
+
+bool
+OPENLDAP::Book::is_ekiga_net_book () const
+{
+  return I_am_an_ekiga_net_book;
 }
 
 void
@@ -393,7 +407,7 @@ OPENLDAP::BookInfoParse (struct BookInfo &info)
       }
     }
   }
-  info.urld = url_tmp;
+  info.urld = boost::shared_ptr<LDAPURLDesc> (url_tmp, ldap_url_desc_deleter ());
   pos = info.uri.find ('/', strlen(info.urld->lud_scheme) + 3);
   if (pos != std::string::npos)
     info.uri_host = info.uri.substr (0,pos);
@@ -600,14 +614,14 @@ extern "C" {
 
 	  /* private text or not? */
 	  if (noecho) {
-	    request->private_text (std::string (resbuf), prompt, "");
+	    request->private_text (std::string (resbuf), prompt, "", std::string ());
 	  } else {
 	    std::string dflt;
 	    if (in->defresult)
 	      dflt = std::string (in->defresult);
 	    else
 	      dflt = "";
-	    request->text (std::string(resbuf), prompt, dflt);
+	    request->text (std::string(resbuf), prompt, dflt, std::string ());
 	  }
 	}
 
@@ -901,7 +915,7 @@ OPENLDAP::Book::refresh_result ()
   } while (msg_result != NULL);
 
   // Do not count ekiga.net's first entry "Search Results ... 100 entries"
-  if (strcmp (bookinfo.uri_host.c_str(), "ldap://ekiga.net") == 0)
+  if (bookinfo.uri_host == EKIGA_NET_URI)
     nbr--;
   c_status = g_strdup_printf (ngettext ("%d user found",
 					"%d users found", nbr), nbr);
@@ -927,9 +941,9 @@ OPENLDAP::BookForm (boost::shared_ptr<Ekiga::FormRequestSimple> request,
 
   request->instructions (_("Please edit the following fields"));
 
-  request->text ("name", _("Book _Name"), info.name);
-  request->text ("uri", _("Server _URI"), info.uri_host);
-  request->text ("base", _("_Base DN"), info.urld->lud_dn);
+  request->text ("name", _("Book _Name:"), info.name, _("Book name, as shown in your dialog box"));
+  request->text ("uri", _("Server _URI:"), info.uri_host, _("Name of LDAP server, prefixed by ldap://"));
+  request->text ("base", _("_Base DN:"), info.urld->lud_dn, std::string ());
 
   {
     std::map<std::string, std::string> choices;
@@ -952,12 +966,12 @@ OPENLDAP::BookForm (boost::shared_ptr<Ekiga::FormRequestSimple> request,
    * "DisplayName" (i.e., "the name that will be displayed") but on
    * most LDAP servers it's "CommonName".
    */
-  request->text ("nameAttr", _("_DisplayName Attribute"), info.urld->lud_attrs[0]);
-  request->text ("callAttr", _("Call _Attributes"), callAttr);
+  request->text ("nameAttr", _("_DisplayName Attribute:"), info.urld->lud_attrs[0], std::string ());
+  request->text ("callAttr", _("Call _Attributes:"), callAttr, _("The field you are searching for"));
   if (info.urld->lud_filter != NULL)
-    request->text ("filter", _("_Filter Template"), info.urld->lud_filter);
+    request->text ("filter", _("_Filter Template:"), info.urld->lud_filter, _("Here, a \"$\" is replaced by the search string"));
   else
-    request->text ("filter", _("_Filter Template"), "");
+    request->text ("filter", _("_Filter Template:"), "", _("Here, a \"$\" is replaced by the search string"));
 
   /* Translators: Bind ID - In LDAP, the operation that begins an LDAP
    * session and authenticates the user to the directory is called a
@@ -968,8 +982,8 @@ OPENLDAP::BookForm (boost::shared_ptr<Ekiga::FormRequestSimple> request,
    * course, the Bind ID can be left blank, in which case the session
    * is anonymous / unauthenticated.)
    */
-  request->text ("authcID", _("Bind _ID"), info.authcID);
-  request->private_text ("password", _("_Password"), info.password);
+  request->text ("authcID", _("Bind _ID:"), info.authcID, _("User ID; leave blank for anonymous / nonauthenticated"));
+  request->private_text ("password", _("_Password:"), info.password, _("The password for the user ID above, if any"));
   request->boolean ("startTLS", _("Use TLS"), info.starttls);
   request->boolean ("sasl", _("Use SASL"), info.sasl);
   {
@@ -1077,8 +1091,7 @@ OPENLDAP::BookFormInfo (Ekiga::Form &result,
   url_base->lud_filter = NULL;
   ldap_free_urldesc (url_base);
 
-  if (bookinfo.urld) ldap_free_urldesc (bookinfo.urld);
-  bookinfo.urld = url_host;
+  bookinfo.urld = boost::shared_ptr<LDAPURLDesc> (url_host, ldap_url_desc_deleter ());
   url_str = ldap_url_desc2str (url_host);
   bookinfo.uri = std::string(url_str);
   ldap_memfree (url_str);
@@ -1119,6 +1132,12 @@ OPENLDAP::Book::on_edit_form_submitted (bool submitted,
   robust_xmlNodeSetContent (node, &authcID_node, "authcID", bookinfo.authcID);
 
   robust_xmlNodeSetContent (node, &password_node, "password", bookinfo.password);
+
+  if (bookinfo.uri_host == EKIGA_NET_URI)
+    I_am_an_ekiga_net_book = true;
+  else
+    I_am_an_ekiga_net_book = false;
+
   updated ();
   trigger_saving ();
 }
