@@ -44,7 +44,7 @@
 #include "common.h"
 
 #include "services.h"
-#include "runtime-glib.h"
+#include "runtime.h"
 
 #include "statusicon.h"
 
@@ -75,22 +75,6 @@ class GnomeMeeting : public PProcess
    */
   ~GnomeMeeting ();
 
-  
-  /* DESCRIPTION  : / 
-   * BEHAVIOR     : Vroom.
-   * PRE          : /
-   */
-  void InitEngine (int argc,
-		   char* argv[]);
-
-  
-  /* DESCRIPTION  : / 
-   * BEHAVIOR     : No more vroom.
-   * PRE          : /
-   */
-  void StopEngine ();
-
-
 
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Prepare the endpoint to exit by removing all
@@ -112,14 +96,14 @@ class GnomeMeeting : public PProcess
    * BEHAVIOR     :  Returns a pointer to the preferences window GMObject.
    * PRE          :  /
    */
-  GtkWidget *GetPrefsWindow (bool create = true);
+  GtkWidget* GetPrefsWindow ();
  
   
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Returns a pointer to the assistant window.
    * PRE          :  /
    */
-  GtkWidget *GetAssistantWindow (bool create = true);
+  GtkWidget* GetAssistantWindow ();
   
   
   /* DESCRIPTION  :  /
@@ -138,13 +122,6 @@ class GnomeMeeting : public PProcess
 
   /* Needed for PProcess */
   void Main();
-
-
-  /* DESCRIPTION  :  /
-   * BEHAVIOR     :  Return the ServiceCore.
-   * PRE          :  /
-   */
-  Ekiga::ServiceCore *GetServiceCore ();
   
 
   static GnomeMeeting *Process ();
@@ -157,7 +134,7 @@ class GnomeMeeting : public PProcess
    *                 stored in config.
    * PRE          :  /
    */
-  void BuildGUI ();
+  void BuildGUI (Ekiga::ServiceCorePtr services);
 
  private:
   
