@@ -39,30 +39,31 @@
 
 #include "account.h"
 #include "bank.h"
+#include "opal-bank.h"
 #include "account-core.h"
-#include "audiooutput-core.h"
 
 #include "callbacks.h"
-#include "misc.h"
-#include "main.h"
-#include "preferences.h"
 
 #include "gmconf.h"
-#include "gmdialog.h"
+#include "gmwindow.h"
 
 #include "services.h"
+#include "menu-builder-tools.h"
 #include "menu-builder-gtk.h"
 #include "form-dialog-gtk.h"
+#include "optional-buttons-gtk.h"
 
 typedef struct GmAccountsWindow_ {
 
-  GmAccountsWindow_ (Ekiga::ServiceCore & _core) : core (_core) {};
+  GmAccountsWindow_ (Ekiga::ServiceCore & _core) : core (_core)
+  {}
 
   GtkWidget *accounts_list;
   GtkWidget *menu_item_core;
   GtkAccelGroup *accel;
 
   Ekiga::ServiceCore &core;
+  OptionalButtonsGtk toolbar;
 
 } GmAccountsWindow;
 
@@ -81,7 +82,7 @@ static void gm_aw_destroy (gpointer aw);
 /* DESCRIPTION  : /
  * BEHAVIOR     : Returns a pointer to the private GmAccountsWindow structure
  *                used by the preferences window GMObject.
- * PRE          : The given GtkWidget pointer must be a preferences window 
+ * PRE          : The given GtkWidget pointer must be a preferences window
  * 		  GMObject.
  */
 static GmAccountsWindow *gm_aw_get_aw (GtkWidget *account_window);
@@ -99,28 +100,33 @@ static gint account_clicked_cb (GtkWidget *w,
 				GdkEventButton *e,
 				gpointer data);
 
-
 /* DESCRIPTION  :  This callback is called when the user clicks
- *                 on an account to enable it in the accounts window.
- * BEHAVIOR     :  It updates the accounts list configuration to enable/disable
- *                 the account. It also calls the Register operation from
- *                 the GMManager to refresh the status of that account.
- * PRE          :  /
+ *                 on a "active" toggle in the accounts window.
+ * BEHAVIOR     :  It tries to enable/disable the account
+ * PRE          :  data is a valid pointer to the GmAccountsWindow.
  */
-static void account_toggled_cb (GtkCellRendererToggle *cell,
-				gchar *path_str,
+static void account_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle* renderer,
+				gchar* path_string,
 				gpointer data);
 
+/* DESCRIPTION  :  This callback is called when the user clicks
+ *                 on an account in the accounts window.
+ * BEHAVIOR     :  It updates the toolbar actions to point to the right account,
+ *                 and to be active/inactive depending if the action is
+ *                 really available or not.
+ * PRE          :  the 'data' is a pointer to the account window.
+ */
+static void on_selection_changed (GtkTreeSelection* /*selection*/,
+				  gpointer data);
 
 /* Columns for the VoIP accounts */
 enum {
 
   COLUMN_ACCOUNT,
+  COLUMN_ACCOUNT_IS_ENABLED,
   COLUMN_ACCOUNT_WEIGHT,
-  COLUMN_ACCOUNT_ENABLED,
   COLUMN_ACCOUNT_ACCOUNT_NAME,
-  COLUMN_ACCOUNT_VOICEMAILS,
-  COLUMN_ACCOUNT_ERROR_MESSAGE,
+  COLUMN_ACCOUNT_STATUS,
   COLUMN_ACCOUNT_STATE,
   COLUMN_ACCOUNT_NUMBER
 };
@@ -145,138 +151,7 @@ gm_aw_get_aw (GtkWidget *accounts_window)
 }
 
 
-bool
-gm_accounts_window_update_account_state (GtkWidget *accounts_window,
-					 gboolean refreshing,
-                                         const Ekiga::Account & _account,
-					 const gchar *status,
-					 const gchar *voicemails)
-{
-  GtkTreeModel *model = NULL;
-
-  GtkTreeIter iter;
-
-  Ekiga::Account *account = NULL;
-  GmAccountsWindow *aw = NULL;
-
-  gchar *error = NULL;
-  gchar *mwi = NULL;
-
-  bool status_modified = false;
-  bool mwi_modified = false;
-
-  g_return_val_if_fail (accounts_window != NULL, false);
-
-  aw = gm_aw_get_aw (accounts_window);
-
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
-
-  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter)){
-
-    do {
-
-      gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
-			  COLUMN_ACCOUNT, &account,
-			  -1);
-
-      if (account == &_account) {
-
-        gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
-                            COLUMN_ACCOUNT_ERROR_MESSAGE, &error,
-                            COLUMN_ACCOUNT_VOICEMAILS, &mwi,
-                            -1);
-
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			    COLUMN_ACCOUNT_STATE, refreshing, -1);
-	if (status) {
-
-	  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			      COLUMN_ACCOUNT_ERROR_MESSAGE, status, -1);
-          status_modified = (error == NULL) || strcmp (status, error);
-        }
-	if (voicemails) {
-
-	  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			      COLUMN_ACCOUNT_VOICEMAILS, voicemails, -1);
-          mwi_modified = (mwi == NULL) || strcmp (voicemails, mwi);
-        }
-      
-        g_free (error);
-        g_free (mwi);
-      }
-
-    } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter));
-  }
-
-  return (status_modified || mwi_modified);
-}
-
-
 /* Engine callbacks */
-static void 
-on_registration_event (const Ekiga::Account & account,
-                       Ekiga::AccountCore::RegistrationState state,
-                       std::string info,
-                       gpointer window)
-{
-  bool is_processing = false;
-  std::string status;
-
-  switch (state) {
-  case Ekiga::AccountCore::Registered:
-    status = _("Registered");
-    break;
-
-  case Ekiga::AccountCore::Unregistered:
-    status = _("Unregistered");
-    break;
-
-  case Ekiga::AccountCore::UnregistrationFailed:
-    status = _("Could not unregister");
-    if (!info.empty ())
-      status = status + "(" + info + ")";
-    break;
-
-  case Ekiga::AccountCore::RegistrationFailed:
-    status = _("Could not register");
-    if (!info.empty ())
-      status = status + "(" + info + ")";
-    break;
-
-  case Ekiga::AccountCore::Processing:
-    status = _("Processing...");
-    is_processing = true;
-  default:
-    break;
-  }
-
-  gm_accounts_window_update_account_state (GTK_WIDGET (window), is_processing, account, status.c_str (), NULL); 
-}
-
-
-static void 
-on_mwi_event (const Ekiga::Account & account,
-              std::string mwi,
-              gpointer self)
-{
-  if (gm_accounts_window_update_account_state (GTK_WIDGET (self), false, account, NULL, mwi.c_str ())) {
-
-    std::string::size_type loc = mwi.find ("/", 0);
-    if (loc != std::string::npos) {
-
-      GmAccountsWindow *aw = gm_aw_get_aw (GTK_WIDGET (self));
-      gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
-	= aw->core.get ("audiooutput-core");
-      std::stringstream new_messages;
-      int i;
-      new_messages << mwi.substr (0, loc);
-      new_messages >> i;
-      if (i > 0)
-        audiooutput_core->play_event ("new_voicemail_sound");
-    }
-  }
-}
-
 
 static void
 populate_menu (GtkWidget *window)
@@ -297,8 +172,7 @@ populate_menu (GtkWidget *window)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
 
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = aw->core.get ("account-core");
+  boost::shared_ptr<Ekiga::AccountCore> account_core = aw->core.get<Ekiga::AccountCore> ("account-core");
 
   if (account_core->populate_menu (builder)) {
     item = gtk_separator_menu_item_new ();
@@ -318,7 +192,7 @@ populate_menu (GtkWidget *window)
   }
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLOSE, aw->accel);
   gtk_menu_shell_append (GTK_MENU_SHELL (builder.menu), item);
-  g_signal_connect_swapped (G_OBJECT (item), "activate",
+  g_signal_connect_swapped (item, "activate",
                             G_CALLBACK (gtk_widget_hide),
                             (gpointer) window);
 
@@ -349,9 +223,7 @@ account_clicked_cb (G_GNUC_UNUSED GtkWidget *w,
   tree_view = GTK_TREE_VIEW (aw->accounts_list);
   model = gtk_tree_view_get_model (tree_view);
 
-  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS) {
-
-    populate_menu (GTK_WIDGET (data));
+  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS || event->type == GDK_2BUTTON_PRESS) {
 
     if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (tree_view),
                                        (gint) event->x, (gint) event->y,
@@ -363,80 +235,120 @@ account_clicked_cb (G_GNUC_UNUSED GtkWidget *w,
                             COLUMN_ACCOUNT, &account,
                             -1);
 
-        if (event->button == 3) {
-
-          MenuBuilderGtk builder;
-          account->populate_menu (builder);
-          if (!builder.empty ()) {
-
-            gtk_widget_show_all (builder.menu);
-            gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
-                            NULL, NULL, event->button, event->time);
-            g_signal_connect (G_OBJECT (builder.menu), "hide",
-                              G_CALLBACK (g_object_unref),
-                              (gpointer) builder.menu);
-          }
-          g_object_ref_sink (G_OBJECT (builder.menu));
-        }
+        gtk_tree_path_free (path);
       }
-
-      gtk_tree_path_free (path);
     }
   }
 
+  if (account == NULL)
+    return FALSE;
+
+  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS) {
+
+    populate_menu (GTK_WIDGET (data));
+
+    if (event->button == 3) {
+
+      MenuBuilderGtk builder;
+      account->populate_menu (builder);
+      if (!builder.empty ()) {
+
+        gtk_widget_show_all (builder.menu);
+        gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
+                        NULL, NULL, event->button, event->time);
+        g_signal_connect (builder.menu, "hide",
+                          G_CALLBACK (g_object_unref),
+                          (gpointer) builder.menu);
+      }
+      g_object_ref_sink (G_OBJECT (builder.menu));
+    }
+  }
+  else if (event->type == GDK_2BUTTON_PRESS) {
+
+    Ekiga::TriggerMenuBuilder builder;
+    account->populate_menu (builder);
+  }
+
   return TRUE;
 }
 
-
-static void
-account_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle *cell,
-		    gchar *path_str,
-		    gpointer data)
+static
+void account_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle* renderer,
+			 gchar* path_string,
+			 gpointer data)
 {
-  GmAccountsWindow *aw = NULL;
+  GmAccountsWindow* aw = NULL;
 
-  GtkTreeModel *model = NULL;
-  GtkTreePath *path = NULL;
-  GtkTreeSelection *selection = NULL;
+  GtkTreeModel* model = NULL;
+  GtkTreePath* path = NULL;
   GtkTreeIter iter;
-
-  gboolean fixed = false;
-
-  Ekiga::Account *account = NULL;
+  Ekiga::Account* account = NULL;
+  gboolean is_enabled;
 
   aw = gm_aw_get_aw (GTK_WIDGET (data));
 
-  /* Make sure the toggled row is selected */
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
-  path = gtk_tree_path_new_from_string (path_str);
-  gtk_tree_selection_select_path (selection, path);
-
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
+  path = gtk_tree_path_new_from_string (path_string);
+
   if (gtk_tree_model_get_iter (model, &iter, path)) {
 
     gtk_tree_model_get (model, &iter,
-                        COLUMN_ACCOUNT_ENABLED, &fixed,
-                        COLUMN_ACCOUNT, &account,
-                        -1);
+			COLUMN_ACCOUNT, &account,
+			COLUMN_ACCOUNT_IS_ENABLED, &is_enabled,
+			-1);
 
-    if (fixed)
-      account->disable ();
-    else 
-      account->enable ();
+    if (is_enabled) {
 
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                        COLUMN_ACCOUNT_ENABLED, fixed^1,
-                        COLUMN_ACCOUNT_ERROR_MESSAGE, "",
-                        -1);
+      Ekiga::Activator builder ("disable");
+      account->populate_menu (builder);
+    } else {
+
+
+      Ekiga::Activator builder ("enable");
+      account->populate_menu (builder);
+    }
   }
 
   gtk_tree_path_free (path);
 }
 
+static void
+on_selection_changed (GtkTreeSelection* /*selection*/,
+		      gpointer data)
+{
+  GmAccountsWindow* aw = (GmAccountsWindow*) data;
+  GtkTreeSelection* selection = NULL;
+  GtkTreeModel *model = NULL;
+  GtkTreeIter iter;
+  Ekiga::Account* account = NULL;
 
-static void 
+  g_return_if_fail (aw != NULL);
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
+
+  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+
+    gtk_tree_model_get (model, &iter,
+			COLUMN_ACCOUNT, &account,
+			-1);
+    if (account) {
+
+      aw->toolbar.reset ();
+      account->populate_menu (aw->toolbar);
+    } else {
+
+      aw->toolbar.reset ();
+    }
+
+  } else {
+
+    aw->toolbar.reset ();
+  }
+}
+
+static void
 gm_accounts_window_add_account (GtkWidget *window,
-                                Ekiga::Account & account)
+                                Ekiga::AccountPtr account)
 {
   GmAccountsWindow *aw = NULL;
   GtkTreeModel *model = NULL;
@@ -450,31 +362,32 @@ gm_accounts_window_add_account (GtkWidget *window,
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
 
   gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
-                      COLUMN_ACCOUNT, &account,
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                      COLUMN_ACCOUNT, account.get (),
+		      COLUMN_ACCOUNT_IS_ENABLED, account->is_enabled (),
                       COLUMN_ACCOUNT_WEIGHT, PANGO_WEIGHT_NORMAL,
-                      COLUMN_ACCOUNT_ENABLED, account.is_enabled (),
-                      COLUMN_ACCOUNT_ACCOUNT_NAME, account.get_name ().c_str (),
-                      -1); 
+                      COLUMN_ACCOUNT_ACCOUNT_NAME, account->get_name ().c_str (),
+                      -1);
 }
 
 
 void
 gm_accounts_window_update_account (GtkWidget *accounts_window,
-                                   Ekiga::Account & account)
+                                   Ekiga::AccountPtr account)
 {
-  Ekiga::Account *caccount = NULL;
+  GmAccountsWindow *aw = NULL;
 
   GtkTreeModel *model = NULL;
+  GtkTreeSelection *selection = NULL;
 
   GtkTreeIter iter;
-
-  GmAccountsWindow *aw = NULL;
+  Ekiga::Account *caccount = NULL;
 
   g_return_if_fail (accounts_window != NULL);
 
   aw = gm_aw_get_aw (accounts_window);
 
+  /* on the one end we update the view */
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
 
   if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model), &iter)){
@@ -483,25 +396,43 @@ gm_accounts_window_update_account (GtkWidget *accounts_window,
 
       gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
 			  COLUMN_ACCOUNT, &caccount, -1);
-      
-      if (caccount == &account) {
 
-        gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
-                            COLUMN_ACCOUNT, &account,
+      if (caccount == account.get ()) {
+
+        gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                            COLUMN_ACCOUNT, account.get (),
+			    COLUMN_ACCOUNT_IS_ENABLED, account->is_enabled (),
                             COLUMN_ACCOUNT_WEIGHT, PANGO_WEIGHT_NORMAL,
-                            COLUMN_ACCOUNT_ENABLED, account.is_enabled (),
-                            COLUMN_ACCOUNT_ACCOUNT_NAME, account.get_name ().c_str (),
-                            -1); 
+                            COLUMN_ACCOUNT_ACCOUNT_NAME, account->get_name ().c_str (),
+			    COLUMN_ACCOUNT_STATUS, account->get_status ().c_str (),
+                            -1);
         break;
       }
     } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter));
   }
+
+  /* on the other end, if the updated account is the one which is selected,
+   * we update the actions on it
+   */
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
+  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+
+    gtk_tree_model_get (model, &iter,
+                        COLUMN_ACCOUNT, &caccount,
+                        -1);
+
+    if (caccount == account.get ()) {
+
+      aw->toolbar.reset ();
+      account->populate_menu (aw->toolbar);
+    }
+  }
 }
 
 
 void
 gm_accounts_window_remove_account (GtkWidget *accounts_window,
-                                   Ekiga::Account & account)
+                                   Ekiga::AccountPtr account)
 {
   Ekiga::Account *caccount = NULL;
 
@@ -523,8 +454,8 @@ gm_accounts_window_remove_account (GtkWidget *accounts_window,
 
       gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
 			  COLUMN_ACCOUNT, &caccount, -1);
-      
-      if (caccount == &account) {
+
+      if (caccount == account.get ()) {
 
         gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
         break;
@@ -534,8 +465,8 @@ gm_accounts_window_remove_account (GtkWidget *accounts_window,
 }
 
 
-static bool 
-visit_accounts (Ekiga::Account & account,
+static bool
+visit_accounts (Ekiga::AccountPtr account,
                 gpointer data)
 {
   gm_accounts_window_add_account (GTK_WIDGET (data), account);
@@ -545,43 +476,53 @@ visit_accounts (Ekiga::Account & account,
 
 
 static void
-on_account_added (Ekiga::Account & account,
+on_account_added (Ekiga::BankPtr /*bank*/,
+		  Ekiga::AccountPtr account,
                   gpointer data)
 {
   gm_accounts_window_add_account (GTK_WIDGET (data), account);
 }
 
 
-static void 
-on_account_updated (Ekiga::Account & account,
+static void
+on_account_updated (Ekiga::BankPtr /*bank*/,
+		    Ekiga::AccountPtr account,
                     gpointer data)
 {
   gm_accounts_window_update_account (GTK_WIDGET (data), account);
 }
 
 
-static void 
-on_account_removed (Ekiga::Account & account,
+static void
+on_account_removed (Ekiga::BankPtr /*bank*/,
+		    Ekiga::AccountPtr account,
                     gpointer data)
 {
   gm_accounts_window_remove_account (GTK_WIDGET (data), account);
 }
 
 
-static void 
-on_bank_added (Ekiga::Bank & bank,
+static void
+on_bank_added (Ekiga::BankPtr bank,
                gpointer data)
 {
-  bank.visit_accounts (sigc::bind (sigc::ptr_fun (visit_accounts), data));
+  bank->visit_accounts (boost::bind (&visit_accounts, _1, data));
   populate_menu (GTK_WIDGET (data));
 }
 
+static bool
+on_visit_banks (Ekiga::BankPtr bank,
+		gpointer data)
+{
+  on_bank_added (bank, data);
+  return true;
+}
 
 static bool
-on_handle_questions (Ekiga::FormRequest *request,
+on_handle_questions (Ekiga::FormRequestPtr request,
                      gpointer data)
 {
-  FormDialog dialog (*request, GTK_WIDGET (data));
+  FormDialog dialog (request, GTK_WIDGET (data));
 
   dialog.run ();
 
@@ -602,6 +543,8 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   GtkWidget *item = NULL;
   GtkWidget *event_box = NULL;
   GtkWidget *scroll_window = NULL;
+  GtkWidget* button_box = NULL;
+  GtkWidget* button = NULL;
 
   GtkWidget *frame = NULL;
   GtkWidget *hbox = NULL;
@@ -610,6 +553,8 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   GtkListStore *list_store = NULL;
   GtkTreeViewColumn *column = NULL;
 
+  GtkTreeSelection* selection = NULL;
+
   AtkObject *aobj;
 
   const gchar *column_names [] = {
@@ -618,9 +563,7 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
     "",
     "",
     _("Account Name"),
-    _("Voice Mails"),
-    _("Status"),
-    ""
+    _("Status")
   };
 
   /* The window */
@@ -634,7 +577,7 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 
   aw = new GmAccountsWindow (core);
-  g_object_set_data_full (G_OBJECT (window), "GMObject", 
+  g_object_set_data_full (G_OBJECT (window), "GMObject",
 			  aw, gm_aw_destroy);
 
   /* The menu */
@@ -655,16 +598,15 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_HELP, NULL);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-  g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (help_cb), NULL);
+  g_signal_connect (item, "activate", G_CALLBACK (help_callback), NULL);
 
   /* The accounts list store */
   list_store = gtk_list_store_new (COLUMN_ACCOUNT_NUMBER,
                                    G_TYPE_POINTER,
+				   G_TYPE_BOOLEAN, /* Is account active? */
 				   G_TYPE_INT,
-				   G_TYPE_BOOLEAN, /* Enabled? */
 				   G_TYPE_STRING,  /* Account Name */
-				   G_TYPE_STRING,  /* VoiceMails */  
-				   G_TYPE_STRING,  /* Error Message */  
+				   G_TYPE_STRING,  /* Error Message */
 				   G_TYPE_INT);    /* State */
 
   aw->accounts_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
@@ -676,32 +618,23 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   atk_object_set_name (aobj, _("Accounts"));
 
   renderer = gtk_cell_renderer_toggle_new ();
-  /* Translators:
-   * The following string "A" means "activated" or "active". It's a column
-   * description in the list of configured accounts, it shows if an account
-   * is activated or not (a status the user can choose).
-   */
-  column = gtk_tree_view_column_new_with_attributes (_("A"),
+  column = gtk_tree_view_column_new_with_attributes (_("Active"),
 						     renderer,
-						     "active", 
-						     COLUMN_ACCOUNT_ENABLED,
+						     "active",
+						     COLUMN_ACCOUNT_IS_ENABLED,
 						     NULL);
-  gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 25);
   gtk_tree_view_append_column (GTK_TREE_VIEW (aw->accounts_list), column);
-  gtk_tree_view_column_set_sort_column_id (column, COLUMN_ACCOUNT_ENABLED);
-  g_signal_connect (G_OBJECT (renderer), "toggled",
-  		    G_CALLBACK (account_toggled_cb),
-  		    (gpointer) window);
+  g_signal_connect (renderer, "toggled",
+		    G_CALLBACK (account_toggled_cb),
+		    (gpointer)window);
 
-
-  /* Add all text renderers, ie all except the 
-   * "ACCOUNT_ENABLED/DEFAULT" columns */
+  /* Add all text renderers */
   for (int i = COLUMN_ACCOUNT_ACCOUNT_NAME ; i < COLUMN_ACCOUNT_NUMBER - 1 ; i++) {
 
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (column_names [i],
 						       renderer,
-						       "text", 
+						       "text",
 						       i,
 						       "weight",
 						       COLUMN_ACCOUNT_WEIGHT,
@@ -713,13 +646,18 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
     gtk_tree_view_column_set_sort_column_id (column, i);
   }
 
-  g_signal_connect (G_OBJECT (aw->accounts_list), "event_after",
+  g_signal_connect (aw->accounts_list, "event_after",
 		    G_CALLBACK (account_clicked_cb), window);
-  
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+  g_signal_connect (selection, "changed",
+		    G_CALLBACK (on_selection_changed), aw);
+
   /* The scrolled window with the accounts list store */
   scroll_window = gtk_scrolled_window_new (FALSE, FALSE);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window), 
-				  GTK_POLICY_AUTOMATIC, 
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window),
+				  GTK_POLICY_AUTOMATIC,
 				  GTK_POLICY_AUTOMATIC);
 
   event_box = gtk_event_box_new ();
@@ -729,7 +667,7 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
 
   frame = gtk_frame_new (NULL);
   gtk_widget_set_size_request (GTK_WIDGET (frame), 250, 150);
-  gtk_container_set_border_width (GTK_CONTAINER (frame), 
+  gtk_container_set_border_width (GTK_CONTAINER (frame),
 				  2 * GNOMEMEETING_PAD_SMALL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
   gtk_container_add (GTK_CONTAINER (frame), scroll_window);
@@ -737,35 +675,50 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   gtk_container_set_border_width (GTK_CONTAINER (aw->accounts_list), 0);
   gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 
+  /* setting up a horizontal button box
+   * (each button with be dynamically disabled/enabled as needed)
+   */
+  button_box = gtk_vbutton_box_new ();
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (button_box), GTK_BUTTONBOX_CENTER);
+  button = gtk_button_new_with_label (_("Enable"));
+  gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
+  aw->toolbar.add_button ("enable", GTK_BUTTON (button));
+  button = gtk_button_new_with_label (_("Disable"));
+  gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
+  aw->toolbar.add_button ("disable", GTK_BUTTON (button));
+  button = gtk_button_new_with_label (_("Edit"));
+  gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
+  aw->toolbar.add_button ("edit", GTK_BUTTON (button));
+  button = gtk_button_new_with_label (_("Remove"));
+  gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
+  aw->toolbar.add_button ("remove", GTK_BUTTON (button));
+  gtk_box_pack_start (GTK_BOX (hbox), button_box, FALSE, FALSE, 10);
+
   populate_menu (window); // This will add static and dynamic actions
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), menu_bar, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), event_box, TRUE, TRUE, 0);
 
-
   /* Generic signals */
-  g_signal_connect_swapped (GTK_OBJECT (window), 
-			    "response", 
-			    G_CALLBACK (gnomemeeting_window_hide),
+  g_signal_connect_swapped (window, "response",
+			    G_CALLBACK (gm_window_hide),
 			    (gpointer) window);
 
-  g_signal_connect (GTK_OBJECT (window), "delete-event", 
-		    G_CALLBACK (delete_window_cb), NULL);
+  gm_window_hide_on_delete (window);
 
   gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (window)->vbox));
 
-  
-  /* Engine Signals callbacks */
-  // FIXME sigc::connection conn;
 
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = core.get ("account-core");
-  account_core->bank_added.connect (sigc::bind (sigc::ptr_fun (on_bank_added), window));
-  account_core->account_added.connect (sigc::bind (sigc::ptr_fun (on_account_added), window));
-  account_core->account_updated.connect (sigc::bind (sigc::ptr_fun (on_account_updated), window));
-  account_core->account_removed.connect (sigc::bind (sigc::ptr_fun (on_account_removed), window));
-  account_core->questions.add_handler (sigc::bind (sigc::ptr_fun (on_handle_questions), (gpointer) window));
-  account_core->registration_event.connect (sigc::bind (sigc::ptr_fun (on_registration_event), (gpointer) window));
-  account_core->mwi_event.connect (sigc::bind (sigc::ptr_fun (on_mwi_event), (gpointer) window));
-  
+  /* Engine Signals callbacks */
+  // FIXME boost::signals::connection conn;
+
+  boost::shared_ptr<Ekiga::AccountCore> account_core = core.get<Ekiga::AccountCore> ("account-core");
+  account_core->bank_added.connect (boost::bind (&on_bank_added, _1, window));
+  account_core->account_added.connect (boost::bind (&on_account_added, _1, _2, window));
+  account_core->account_updated.connect (boost::bind (&on_account_updated, _1, _2, window));
+  account_core->account_removed.connect (boost::bind (&on_account_removed, _1, _2, window));
+  account_core->questions.connect (boost::bind (&on_handle_questions, _1, (gpointer) window));
+
+  account_core->visit_banks (boost::bind (&on_visit_banks, _1, window));
+
   return window;
 }
